diff PalanthirServer/Internals/StoreScp.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children
line wrap: on
line diff
--- a/PalanthirServer/Internals/StoreScp.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirServer/Internals/StoreScp.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include "../FromDcmtkBridge.h"
 #include "../ToDcmtkBridge.h"
-#include "../../Core/PalantirException.h"
+#include "../../Core/PalanthirException.h"
 
 #include <dcmtk/dcmdata/dcfilefo.h>
 #include <dcmtk/dcmdata/dcmetinf.h>
@@ -31,7 +31,7 @@
 #include <dcmtk/dcmnet/diutil.h>
 
 
-namespace Palantir
+namespace Palanthir
 {
   namespace Internals
   {
@@ -188,7 +188,7 @@
               {
                 cbdata->handler->Handle(buffer, summary, dicomJson, cbdata->distantAET);
               }
-              catch (PalantirException& e)
+              catch (PalanthirException& e)
               {
                 rsp->DimseStatus = STATUS_STORE_Refused_OutOfResources;
                 OFLOG_ERROR(Internals::Logger, "Exception while storing DICOM: " << e.What());
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium